@@ -12,7 +12,8 @@ import pandas as pd
 from datasets import Dataset
 
 SPECIAL_COL_SEP = "___"
-
+NUMERIC_NA_TOKEN = "@"
+INVALID_NUMS_RE = r"[^\-.0-9]"
 
 @dataclass(frozen=True)
 class ModelType:
@@ -231,12 +232,16 @@ def decode_partition_numeric_col(partition_col):
     return "_".join(partition_col.split("_")[:-1])
 
 
-def tokenize_numeric_col(series, nparts=2, col_zfill=2):
+def tokenize_numeric_col(series: pd.Series, nparts=2, col_zfill=2):
     # After normalizing the numeric values, we then segment
     # them based on a fixed partition size (nparts).
     col = series.name
     max_len = series.map(len).min()
 
+    # Take the observations that have non-numeric characters.
+    # These are NaNs.
+    nan_obs = series.str.contains(INVALID_NUMS_RE, regex=True)
+
     if nparts > max_len > 2:
         # Allow minimum of 0-99 as acceptable singleton range.
         raise ValueError(
@@ -245,6 +250,10 @@ def tokenize_numeric_col(series, nparts=2, col_zfill=2):
     mx = series.map(len).max()
 
     tr = pd.concat([series.str[i : i + nparts] for i in range(0, mx, nparts)], axis=1)
+
+    # Replace values with NUMERIC_NA_TOKEN
+    tr.loc[nan_obs] = NUMERIC_NA_TOKEN * nparts
+
     tr.columns = encode_partition_numeric_col(col, tr, col_zfill)
 
     return tr
