@@ -156,7 +156,7 @@ class REaLSampler:
                     # data for object types, but are integral, in the
                     # fb-comments dataset.
                     try:
-                        series = series.astype(pd.Int64Dtype())
+                        series = series.astype(pd.Int64Dtype()).astype(str)
                     except TypeError:
                         pass
                     except ValueError:
